// main11.cc is a part of the PYTHIA event generator.
// Copyright (C) 2012 Torbjorn Sjostrand.
// PYTHIA is licenced under the GNU GPL version 2, see COPYING for details.
// Please respect the MCnet Guidelines, see GUIDELINES for details.

// This is a simple test program. 
// It illustrates how Les Houches Event File input can be used in Pythia8.
// It uses the Wproduction.lhe input file, the latter with 5k events.

#include "Vincia/Vincia.h"

using namespace Pythia8;
using namespace Vincia;

int main() {
  
  // Define Pythia 8 generator with plug-in
  Pythia pythia;
  VinciaPlugin vincia(&pythia,"vincia25.cmnd");
  
  // Initialize Vincia & Pythia
  vincia.init();
  
  // Allow abort of run if many errors
  int  nAbort  = pythia.settings.mode("Main:timesAllowErrors");
  int  iAbort  = 0;
  bool doAbort = false;
  
  // Number of events
  int nEvent        = pythia.settings.mode("Main:numberOfEvents");
  double nEventUsed = 0.0;

  // Sum of weights
  double weightSum   = 0.0;
  
  // Begin event loop
  for (int iEvent = 1; iEvent <= nEvent; ++iEvent) {

    // Generate next event
    // Break out of event loop if at end of LHE file
    if ( !pythia.next() ) {
      if ( pythia.info.atEndOfFile() ) break;
      else if (++iAbort > nAbort) { doAbort = true; break; }
      else continue;
    }
    
    // Get weights
    double weightInit = vincia.weightInit();
    // Pythia's weight is already accounted for in the CS
    weightSum        += weightInit/pythia.info.weight();
    
    // Count number of actual events
    nEventUsed += 1.0;

  // End of event loop.      
  }
  
  if (doAbort) 
    cout << endl << endl << "Aborting due to too many errors!" 
         << endl << endl;
  
  // Print infos
  cout << "Cross Section: " << scientific << pythia.info.sigmaGen() << " * " << weightSum/nEventUsed
       << " = " << pythia.info.sigmaGen()*weightSum/nEventUsed << " mb " << endl << endl;
  cout.precision(3); 
  cout << fixed;
  vincia.printInfo();
  pythia.stat();

  // Done.                           
  return 0;
}
